@@ -25,6 +25,7 @@ func (o Options) Run() error {
 		command:    o.Command,
 		align:      o.Align,
 		showOutput: o.ShowOutput && isTTY,
+		showError:  o.ShowError,
 		timeout:    o.Timeout,
 		hasTimeout: o.Timeout > 0,
 	}
@@ -40,19 +41,26 @@ func (o Options) Run() error {
 		return exit.ErrAborted
 	}
 
-	if err != nil {
-		return fmt.Errorf("failed to access stdout: %w", err)
-	}
-
-	if o.ShowOutput {
-		// BubbleTea writes the View() to stderr.
-		// If the program is being piped then put the accumulated output in stdout.
-		if !isTTY {
-			_, err := os.Stdout.WriteString(m.stdout)
-			if err != nil {
-				return fmt.Errorf("failed to write to stdout: %w", err)
+	// If the command succeeds, and we are printing output and we are in a TTY then push the STDOUT we got to the actual
+	// STDOUT for piping or other things.
+	if m.status == 0 {
+		if o.ShowOutput {
+			// BubbleTea writes the View() to stderr.
+			// If the program is being piped then put the accumulated output in stdout.
+			if !isTTY {
+				_, err := os.Stdout.WriteString(m.stdout)
+				if err != nil {
+					return fmt.Errorf("failed to write to stdout: %w", err)
+				}
 			}
 		}
+	} else if o.ShowError {
+		// Otherwise if we are showing errors and the command did not exit with a 0 status code then push all of the command
+		// output to the terminal. This way failed commands can be debugged.
+		_, err := os.Stdout.WriteString(m.output)
+		if err != nil {
+			return fmt.Errorf("failed to write to stdout: %w", err)
+		}
 	}
 
 	os.Exit(m.status)
