@@ -15,12 +15,15 @@
 package spin
 
 import (
+	"io"
+	"os"
 	"os/exec"
 	"strings"
 	"time"
 
 	"github.com/charmbracelet/gum/internal/exit"
 	"github.com/charmbracelet/gum/timeout"
+	"github.com/mattn/go-isatty"
 
 	"github.com/charmbracelet/bubbles/spinner"
 	tea "github.com/charmbracelet/bubbletea"
@@ -31,19 +34,26 @@ type model struct {
 	title      string
 	align      string
 	command    []string
+	quitting   bool
 	aborted    bool
 	status     int
 	stdout     string
+	stderr     string
+	output     string
 	showOutput bool
+	showError  bool
 	timeout    time.Duration
 	hasTimeout bool
 }
 
+var bothbuf strings.Builder
 var outbuf strings.Builder
 var errbuf strings.Builder
 
 type finishCommandMsg struct {
 	stdout string
+	stderr string
+	output string
 	status int
 }
 
@@ -55,8 +65,15 @@ func commandStart(command []string) tea.Cmd {
 		}
 		cmd := exec.Command(command[0], args...) //nolint:gosec
 
-		cmd.Stdout = &outbuf
-		cmd.Stderr = &errbuf
+		if isatty.IsTerminal(os.Stdout.Fd()) {
+			stdout := io.MultiWriter(&bothbuf, &errbuf)
+			stderr := io.MultiWriter(&bothbuf, &outbuf)
+
+			cmd.Stdout = stdout
+			cmd.Stderr = stderr
+		} else {
+			cmd.Stdout = os.Stdout
+		}
 
 		_ = cmd.Run()
 
@@ -68,6 +85,8 @@ func commandStart(command []string) tea.Cmd {
 
 		return finishCommandMsg{
 			stdout: outbuf.String(),
+			stderr: errbuf.String(),
+			output: bothbuf.String(),
 			status: status,
 		}
 	}
@@ -81,6 +100,10 @@ func (m model) Init() tea.Cmd {
 	)
 }
 func (m model) View() string {
+	if m.quitting && m.showOutput {
+		return strings.TrimPrefix(errbuf.String()+"\n"+outbuf.String(), "\n")
+	}
+
 	var str string
 	if m.hasTimeout {
 		str = timeout.Str(m.timeout)
@@ -102,6 +125,9 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	switch msg := msg.(type) {
 	case timeout.TickTimeoutMsg:
 		if msg.TimeoutValue <= 0 {
+			// grab current output before closing for piped instances
+			m.stdout = outbuf.String()
+
 			m.status = exit.StatusAborted
 			return m, tea.Quit
 		}
@@ -109,7 +135,10 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		return m, timeout.Tick(msg.TimeoutValue, msg.Data)
 	case finishCommandMsg:
 		m.stdout = msg.stdout
+		m.stderr = msg.stderr
+		m.output = msg.output
 		m.status = msg.status
+		m.quitting = true
 		return m, tea.Quit
 	case tea.KeyMsg:
 		switch msg.String() {
